/*
 *  Copyright 2010 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.survey.control');

org.ametys.survey.control.RedirectPageActionButton = function(id, configuration, pluginName)
{
	org.ametys.survey.control.RedirectPageActionButton.superclass.constructor.call(this, id, configuration, pluginName);
}

Ext.extend(org.ametys.survey.control.RedirectPageActionButton, org.ametys.ribbon.control.button.ActionSelectionButton, {});

org.ametys.survey.control.RedirectPageActionButton.prototype.onMessage = function(messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var allTargets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(allTargets, this._testTarget.createDelegate(this));

			if (target != null)
			{
				this._currentSurveyId = target.getParameters().id;
				this._currentLang = target.getParameters().lang;
				
				this.getElements().each(function(element) { element.setDisabled(true); element.toggle(false); element.refreshing(); });
				this.updateTooltip(this.getConfiguration()["refresh-description"]);
				org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {target: this._currentSurveyId});
			}
			else
			{
				this._currentSurveyId = null;
				this._currentLang = null;
				
				this.getElements().each(function(element) { element.disable();  element.toggle(false); });
			}
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED)
		{
			var allTargets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(allTargets, this._testTarget.createDelegate(this));
			
			if (target != null && this._currentSurveyId == target.getParameters().id)
			{
				this.getElements().each(function(element) { element.setDisabled(true); element.toggle(false); element.refreshing(); });
				this.updateTooltip(this.getConfiguration()["refresh-description"]);
				org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {target: this._currentSurveyId});
			}
		}
	}
}

org.ametys.survey.control.RedirectPageActionButton.prototype.configurationChanged = function(params)
{
	this.getElements().each(function(element) { element.stopRefreshing(); });

	var tooltip = this._getTooltip(this.getConfiguration()["default-description"], params);
	
	var toggleState = this._isToggle(params);
	this.getElements().each(function(element) { element.allowDepress = false; element.toggle(toggleState); });
	
	this.getElements().each(function(element) { element.setDisabled(false); });
	
	this.updateTooltip(tooltip, this.getElements().get(0).iconLarge, null);
	
	this._lastParams = params;
}

org.ametys.survey.control.RedirectPageActionButton.prototype._isToggle = function (params)
{
	return params['page-redirection'] != null;
}

org.ametys.survey.control.RedirectPageActionButton.prototype._getTooltip = function (tooltip, params)
{
	this._redirectPageId = params['page-redirection'];
	if (this._redirectPageId != null)
	{
		if (tooltip != "")
		{
			tooltip += "<br/><br/>";
		}
		tooltip += params["page-redirection-description"];
		
		if (tooltip != "")
		{
			tooltip += "<br/><br/>";
		}
		tooltip += this.getConfiguration()["redirect-page-description-end"];
	}
	
	return tooltip;
}